@@ -3,7 +3,8 @@ import pytest
 import torch
 
 from mmseg.models.backbones import MixVisionTransformer
-from mmseg.models.backbones.mit import EfficientMultiheadAttention, MixFFN
+from mmseg.models.backbones.mit import (EfficientMultiheadAttention, MixFFN,
+                                        TransformerEncoderLayer)
 
 
 def test_mit():
@@ -56,6 +57,14 @@ def test_mit():
     outs = MHA(temp, hw_shape, temp)
     assert out.shape == (1, token_len, 64)
 
+    # Test TransformerEncoderLayer with checkpoint forward
+    block = TransformerEncoderLayer(
+        embed_dims=64, num_heads=4, feedforward_channels=256, with_cp=True)
+    assert block.with_cp
+    x = torch.randn(1, 56 * 56, 64)
+    x_out = block(x, (56, 56))
+    assert x_out.shape == torch.Size([1, 56 * 56, 64])
+
 
 def test_mit_init():
     path = 'PATH_THAT_DO_NOT_EXIST'
